/**
 * Copyright (c) 2000-2010 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portlet.xslcontent.action;

import com.liferay.portal.kernel.portlet.BaseConfigurationAction;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.servlet.SessionMessages;
import com.liferay.portal.kernel.util.ArrayUtil;
import com.liferay.portal.kernel.util.Constants;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.WebKeys;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portlet.PortletPreferencesFactoryUtil;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletConfig;
import javax.portlet.PortletPreferences;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import java.net.MalformedURLException;
import java.net.URL;

/**
 * @author Brian Wing Shun Chan
 */
public class ConfigurationActionImpl extends BaseConfigurationAction {

	public void processAction(
			PortletConfig portletConfig, ActionRequest actionRequest,
			ActionResponse actionResponse)
		throws Exception {

		String cmd = ParamUtil.getString(actionRequest, Constants.CMD);

		if (!cmd.equals(Constants.UPDATE)) {
			return;
		}

		ThemeDisplay themeDisplay = (ThemeDisplay)actionRequest.getAttribute(
			WebKeys.THEME_DISPLAY);

		String xmlURL = ParamUtil.getString(actionRequest, "xmlURL");

		xmlURL = StringUtil.replace(
			xmlURL, "@portal_url@", themeDisplay.getPortalURL());

		String xslURL = ParamUtil.getString(actionRequest, "xslURL");

		xslURL = StringUtil.replace(
			xslURL, "@portal_url@", themeDisplay.getPortalURL());

		if (!hasAllowedProtocol(xmlURL)) {
			SessionErrors.add(actionRequest, "xmlURL");
		}
		else if (!hasAllowedProtocol(xslURL)) {
				SessionErrors.add(actionRequest, "xslURL");
		}
		else {
			String portletResource = ParamUtil.getString(
				actionRequest, "portletResource");

			PortletPreferences preferences =
				PortletPreferencesFactoryUtil.getPortletSetup(
					actionRequest, portletResource);

			preferences.setValue("xml-url", xmlURL);
			preferences.setValue("xsl-url", xslURL);

			preferences.store();

			SessionMessages.add(
				actionRequest, portletConfig.getPortletName() + ".doConfigure");
		}
	}

	public String render(
			PortletConfig portletConfig, RenderRequest renderRequest,
			RenderResponse renderResponse)
		throws Exception {

		return "/html/portlet/xsl_content/configuration.jsp";
	}

	protected boolean hasAllowedProtocol(String xmlURL) {
		try {
			URL url = new URL(xmlURL);

			String protocol = url.getProtocol();

			if (ArrayUtil.contains(_PROTOCOLS, protocol)) {
				return true;
			}
		}
		catch (MalformedURLException murle) {
			return false;
		}

		return false;
	}

	private static final String[] _PROTOCOLS = {"http", "https"};
}